@@ -12,7 +12,7 @@ logger = get_task_logger(__name__)
 @app.task
 def test_task(*args):
     transaction.begin()
-    logger.debug(u"Running the task we want with args : %s" % args)
+    logger.debug("Running the task we want with args : %s" % args)
     company = Company.get(args[0])
     logger.debug(company.name)
     transaction.commit()
