@@ -1019,8 +1019,8 @@ def collect_operations_by_fiscal_year(
     )
 
     # Adding last exercice operations if needed
-    if data_type != AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING:
-        return current_exercice_operations
+    # if data_type != AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING:
+    #     return current_exercice_operations
 
     # Has the closure been done for former year ?
     former_closure_year = upload_date.year - 1
