@@ -23,7 +23,7 @@ def scheduled_render_pdf_task(document_id):
     if document is None:
         raise Exception("Document doesn't exist in database")
 
-    request = celery_app.conf['PYRAMID_REQUEST']
+    request = celery_app.conf["PYRAMID_REQUEST"]
     try:
         # Ensure layout_manager
         setup_rendering_hacks(request, document)
@@ -44,23 +44,19 @@ def async_internalestimation_valid_callback(document_id):
     - Create a Supplier Order and attache the pdf file
     """
     logger.debug(
-        "Async internal estimation validation callback for {}".format(
-            document_id
-        )
+        "Async internal estimation validation callback for {}".format(document_id)
     )
     document = utils.get_task(document_id)
     if document is None:
         logger.error(
-            "Document with id {} doesn't exist in database".format(
-                document_id
-            )
+            "Document with id {} doesn't exist in database".format(document_id)
         )
         return
     else:
         logger.debug("Found the document {}".format(document))
         logger.debug(id(document))
 
-    request = celery_app.conf['PYRAMID_REQUEST']
+    request = celery_app.conf["PYRAMID_REQUEST"]
     # Ensure layout_manager
     try:
         logger.debug("Setup rendering hacks")
@@ -84,20 +80,16 @@ def async_internalinvoice_valid_callback(document_id):
     - Create a Supplier Invoice and attach the pdf file
     """
     logger.debug(
-        "Async internal invoice validation callback for {}".format(
-            document_id
-        )
+        "Async internal invoice validation callback for {}".format(document_id)
     )
     document = utils.get_task(document_id)
     if document is None:
         logger.error(
-            "Document with id {} doesn't exist in database".format(
-                document_id
-            )
+            "Document with id {} doesn't exist in database".format(document_id)
         )
         return
 
-    request = celery_app.conf['PYRAMID_REQUEST']
+    request = celery_app.conf["PYRAMID_REQUEST"]
     # Ensure layout_manager
     try:
         setup_rendering_hacks(request, document)
